A set of tools for controlling processing workflow with spiders and script running in scrapinghub ScrapyCloud.

# Installation

pip install shub-workflow

# Usage

Check [Project Wiki](https://github.com/scrapinghub/shub-workflow/wiki) for documentation. You can also see code tests for lots of examples of usage.
